@@ -9,8 +9,6 @@ extern record_description Absyn_FunctionArgs_FOR__ITER__FARG__desc;
 
 extern record_description Absyn_ReductionIterType_COMBINE__desc;
 
-const MetaModelica::Record combineIterType{0, Absyn_ReductionIterType_COMBINE__desc};
-
 FunctionArgsIter::FunctionArgsIter(MetaModelica::Record value)
   : _exp{value[0]},
     _iterators{value[2].mapVector<Iterator>()}
@@ -27,6 +25,8 @@ std::unique_ptr<FunctionArgs::Base> FunctionArgsIter::clone() const noexcept
 
 MetaModelica::Value FunctionArgsIter::toAbsyn() const noexcept
 {
+  static const MetaModelica::Record combineIterType{0, Absyn_ReductionIterType_COMBINE__desc};
+
   return MetaModelica::Record(FunctionArgs::FOR_ITER_FARG, Absyn_FunctionArgs_FOR__ITER__FARG__desc, {
     _exp.toAbsyn(),
     combineIterType,
