@@ -690,7 +690,7 @@ static unsigned int cmpDataTubes(int isResultCmp, char* varname, DataField *time
 #else
     fname = (char*) omc_alloc_interface.malloc_atomic(25 + strlen(varname));
     sprintf(fname, "tmp.%s.html.tmp", varname);
-    fout = fopen(fname, "wb+");
+    fout = omc_fopen(fname, "wb+");
     if (!fout)
     {
       perror("Error opening temp file"); fflush(stderr);
@@ -742,7 +742,13 @@ static unsigned int cmpDataTubes(int isResultCmp, char* varname, DataField *time
   } else if (!isResultCmp && (error || keepEqualResults)) {
     fname = (char*) omc_alloc_interface.malloc_atomic(25 + strlen(prefix) + strlen(varname));
     sprintf(fname, "%s.%s.csv", prefix, varname);
-    fout = fopen(fname,"w");
+    fout = omc_fopen(fname,"w");
+    if (!fout)
+    {
+      perror("Error opening file");
+	  fprintf(stderr, "File: %s\n", fname);
+	  fflush(stderr);
+    }
   }
   maxn = intmax(intmax(intmax(ref.size,actual.size),priv->countHigh),priv->countLow);
   if (fout) {
@@ -809,7 +815,6 @@ fprintf(fout, "{title: '%s',\n"
 
     if (isHtml) {
 #if !(_XOPEN_SOURCE >= 700 || _POSIX_C_SOURCE >= 200809L)
-      size_t r;
       if (fseek(fout, 0, SEEK_END))
       {
         perror("Error on fseek end!");
@@ -820,14 +825,11 @@ fprintf(fout, "{title: '%s',\n"
         perror("Error on fseek set!");
       }
       html = (char*)malloc((html_size + 1) * sizeof(char));
-      r = fread(html, sizeof(char), html_size, fout);
-      if (r != html_size)
-      {
-        perror("Error on fread!");
-      }
+      omc_fread(html, sizeof(char), html_size, fout, 0);
+
       html[html_size] = '\0';
       fclose(fout);
-      unlink(fname);
+      omc_unlink(fname);
 #else
       fclose(fout);
 #endif
