@@ -115,8 +115,6 @@ extern "C" {
 
 int functionODE_residual(DATA* data, threadData_t *threadData, double *dx, double *dy, double *dz)
 {
-    TRACE_PUSH
-
     long i;
 
     /* debug */
@@ -152,7 +150,6 @@ int functionODE_residual(DATA* data, threadData_t *threadData, double *dx, doubl
         }
     }
 
-    TRACE_POP
     return 0;
 }
 
@@ -332,7 +329,7 @@ int functionJacBD_num(DATA* data, threadData_t *threadData, double *matrixB, dou
 int functionJacA(DATA* data, threadData_t *threadData, double* jac){
 
   const int index = data->callback->INDEX_JAC_A;
-  ANALYTIC_JACOBIAN* jacobian = &(data->simulationInfo->analyticJacobians[index]);
+  JACOBIAN* jacobian = &(data->simulationInfo->analyticJacobians[index]);
   unsigned int i,j,k;
   k = 0;
   if (jacobian->constantEqns != NULL) {
@@ -378,7 +375,7 @@ int functionJacA(DATA* data, threadData_t *threadData, double* jac){
 int functionJacB(DATA* data, threadData_t *threadData, double* jac){
 
   const int index = data->callback->INDEX_JAC_B;
-  ANALYTIC_JACOBIAN* jacobian = &(data->simulationInfo->analyticJacobians[index]);
+  JACOBIAN* jacobian = &(data->simulationInfo->analyticJacobians[index]);
 
   unsigned int i,j,k;
   k = 0;
@@ -424,7 +421,7 @@ int functionJacB(DATA* data, threadData_t *threadData, double* jac){
 int functionJacC(DATA* data, threadData_t *threadData, double* jac){
 
   const int index = data->callback->INDEX_JAC_C;
-  ANALYTIC_JACOBIAN* jacobian = &(data->simulationInfo->analyticJacobians[index]);
+  JACOBIAN* jacobian = &(data->simulationInfo->analyticJacobians[index]);
   unsigned int i,j,k;
   k = 0;
   if (jacobian->constantEqns != NULL) {
@@ -467,7 +464,7 @@ int functionJacC(DATA* data, threadData_t *threadData, double* jac){
 int functionJacD(DATA* data, threadData_t *threadData, double* jac){
 
   const int index = data->callback->INDEX_JAC_D;
-  ANALYTIC_JACOBIAN* jacobian = &(data->simulationInfo->analyticJacobians[index]);
+  JACOBIAN* jacobian = &(data->simulationInfo->analyticJacobians[index]);
   unsigned int i,j,k;
   k = 0;
   if (jacobian->constantEqns != NULL) {
@@ -513,7 +510,6 @@ int functionJacD(DATA* data, threadData_t *threadData, double* jac){
 
 int linearize(DATA* data, threadData_t *threadData)
 {
-    TRACE_PUSH
     /* Check if data recovery is requested */
     int do_data_recovery = omc_flag[FLAG_L_DATA_RECOVERY] ? 1 : 0;
 
@@ -557,13 +553,11 @@ int linearize(DATA* data, threadData_t *threadData)
         if(functionJacAC_num(data, threadData, matrixA, matrixC, matrixCz))
         {
             throwStreamPrint(threadData, "Error, can not get Matrix A or C ");
-            TRACE_POP
             return 1;
         }
         if(functionJacBD_num(data, threadData, matrixB, matrixD, matrixDz))
         {
             throwStreamPrint(threadData, "Error, can not get Matrix B or D ");
-            TRACE_POP
             return 1;
         }
     }
@@ -572,7 +566,7 @@ int linearize(DATA* data, threadData_t *threadData)
     if (data->simulationInfo->analyticJacobians[data->callback->INDEX_JAC_A].sizeTmpVars > 0){
         /* Retrieve symbolic Jacobian */
         /* Determine Matrix A */
-        ANALYTIC_JACOBIAN* jacobian = &(data->simulationInfo->analyticJacobians[data->callback->INDEX_JAC_A]);
+        JACOBIAN* jacobian = &(data->simulationInfo->analyticJacobians[data->callback->INDEX_JAC_A]);
         if(!data->callback->initialAnalyticJacobianA(data, threadData, jacobian)){
             assertStreamPrint(threadData,0==functionJacA(data, threadData, matrixA),"Error, can not get Matrix A ");
         }
@@ -678,39 +672,51 @@ int linearize(DATA* data, threadData_t *threadData)
       case OMC_LINEARIZE_DUMP_LANGUAGE_PYTHON:    ext = ".py";  break;
     }
     /* ticket #5927: Don't use the model name to prevent bad names for certain languages. */
-    filename = "linearized_model" + string(ext);
+    if (omc_flag[FLAG_OUTPUT_PATH]) {
+      filename = string(omc_flagValue[FLAG_OUTPUT_PATH]) + "/" + "linearized_model" + string(ext);
+    } else {
+      filename = "linearized_model" + string(ext);
+    }
 
     FILE *fout = omc_fopen(filename.c_str(),"wb");
     assertStreamPrint(threadData,0!=fout,"Cannot open File %s",filename.c_str());
 
+    const char* frame = NULL;
     if(do_data_recovery > 0){
-        fprintf(fout, data->callback->linear_model_datarecovery_frame(), strX.c_str(), strU.c_str(), strZ0.c_str(), strA.c_str(), strB.c_str(), strC.c_str(), strD.c_str(), strCz.c_str(), strDz.c_str());
+        frame = data->callback->linear_model_datarecovery_frame();
+        fprintf(fout, frame, strX.c_str(), strU.c_str(), strZ0.c_str(), strA.c_str(), strB.c_str(), strC.c_str(), strD.c_str(), strCz.c_str(), strDz.c_str());
     }else{
-        fprintf(fout, data->callback->linear_model_frame(), strX.c_str(), strU.c_str(), strA.c_str(), strB.c_str(), strC.c_str(), strD.c_str(), (double) data->simulationInfo->stopTime);
-    }
-    if(OMC_ACTIVE_STREAM(OMC_LOG_STATS)) {
-      infoStreamPrint(OMC_LOG_STATS, 0, data->callback->linear_model_frame(), strX.c_str(), strU.c_str(), strA.c_str(), strB.c_str(), strC.c_str(), strD.c_str(), (double) data->simulationInfo->stopTime);
+        frame = data->callback->linear_model_frame();
+        fprintf(fout, frame, strX.c_str(), strU.c_str(), strA.c_str(), strB.c_str(), strC.c_str(), strD.c_str(), (double) data->simulationInfo->stopTime);
     }
 
     fflush(fout);
     fclose(fout);
 
-    if (data->modelData->runTestsuite) {
-        infoStreamPrint(OMC_LOG_STDOUT, 0, "Linear model is created.");
-    }
-    else {
-        char* cwd = getcwd(NULL, 0); /* call with NULL and 0 to allocate the buffer dynamically (no pathmax needed) */
-        if(!cwd) {
-          infoStreamPrint(OMC_LOG_STDOUT, 0, "Linear model %s is created, but getting the full path failed.", filename.c_str());
+    if (0 == strcmp(frame, "")) {
+        errorStreamPrint(OMC_LOG_STDOUT, 0, "Linear model could not be created.");
+    } else {
+        if (data->modelData->runTestsuite) {
+            infoStreamPrint(OMC_LOG_STDOUT, 0, "Linear model is created.");
         }
         else {
-          infoStreamPrint(OMC_LOG_STDOUT, 0, "Linear model is created at %s/%s", cwd, filename.c_str());
-          free(cwd);
+          if (omc_flag[FLAG_OUTPUT_PATH]) {
+            infoStreamPrint(OMC_LOG_STDOUT, 0, "Linear model is created at %s", filename.c_str());
+          } else {
+            char* cwd = getcwd(NULL, 0); /* call with NULL and 0 to allocate the buffer dynamically (no pathmax needed) */
+            if(!cwd) {
+              infoStreamPrint(OMC_LOG_STDOUT, 0, "Linear model %s is created, but getting the full path failed.", filename.c_str());
+            }
+            else {
+              infoStreamPrint(OMC_LOG_STDOUT, 0, "Linear model is created at %s/%s", cwd, filename.c_str());
+              free(cwd);
+            }
+          }
+          infoStreamPrint(OMC_LOG_STDOUT, 0, "The output format can be changed with the command line option --linearizationDumpLanguage.");
+          infoStreamPrint(OMC_LOG_STDOUT, 0, "The options are: --linearizationDumpLanguage=none, modelica, matlab, julia, python.");
+          infoStreamPrint(OMC_LOG_STDOUT, 0, "In OMEdit Simulation Setup->Linearize->Target language for linearized model.");
         }
-        infoStreamPrint(OMC_LOG_STDOUT, 0, "The output format can be changed with the command line option --linearizationDumpLanguage.");
-        infoStreamPrint(OMC_LOG_STDOUT, 0, "The options are: --linearizationDumpLanguage=modelica, matlab, julia, python.");
-    }
-    TRACE_POP
+      }
     return 0;
   }
 
