@@ -34,22 +34,26 @@
 #ifndef _NEWTONITERATION_H_
 #define _NEWTONITERATION_H_
 
-#include "simulation_data.h"
 #include "nonlinearSolverNewton.h"
+#include "nonlinearSystem.h"
+#include "simulation_data.h"
 
 #ifdef __cplusplus
 extern "C" {
 #endif
 
+/**
+ * @brief Struct containing information about equation system to be solved with Newton-Raphson method.
+ */
 typedef struct DATA_NEWTON
 {
-  int initialized; /* 1 = initialized, else = 0*/
-  double* resScaling;
-  double* fvecScaled;
+  int initialized;      /** 1 = initialized, else = 0 */
+  double* resScaling;   /** Residual scaling vector */
+  double* fvecScaled;   /** scaled f vector */
 
   int newtonStrategy;
 
-  int n;
+  int n;                /** size of equation system */
   double* x;
   double* fvec;
   double xtol;
@@ -58,13 +62,13 @@ typedef struct DATA_NEWTON
   int maxfev;
   int info;
   double epsfcn;
-  double* fjac;
+  double* fjac;           /** Jacobian matrix in row-major format */
   double* rwork;
   int* iwork;
   int calculate_jacobian;
   int factorization;
-  int numberOfIterations; /* over the whole simulation time */
-  int numberOfFunctionEvaluations; /* over the whole simulation time */
+  int numberOfIterations;           /** over the whole simulation time */
+  int numberOfFunctionEvaluations;  /** over the whole simulation time */
 
   /* damped newton */
   double* x_new;
@@ -74,14 +78,22 @@ typedef struct DATA_NEWTON
   double* delta_f;
   double* delta_x_vec;
 
-   rtclock_t timeClock;
+  rtclock_t timeClock;
 
+  /* Debug information */
+  double time;                /** Simulation time */
+  modelica_boolean initial;   /** True if in initialization */
+
+  NLS_USERDATA* userData;
 } DATA_NEWTON;
 
+/* Typedef */
+typedef int (genericResidualFunc)(int n, double* x, double* fvec, void* userData, int fj);
 
-int allocateNewtonData(int size, void** data);
-int freeNewtonData(void** data);
-int _omc_newton(int(*f)(int*, double*, double*, void*, int), DATA_NEWTON* solverData, void* userdata);
+
+DATA_NEWTON* allocateNewtonData(int size, NLS_USERDATA* userData);
+void freeNewtonData(DATA_NEWTON* newtonData);
+int _omc_newton(genericResidualFunc f, DATA_NEWTON* solverData, void* userData);
 
 #ifdef __cplusplus
 }
