@@ -63,15 +63,18 @@
 #endif
 
 /* Forward declarations */
-struct DATA;
 typedef struct DATA DATA;
 typedef struct VALUES_LIST VALUES_LIST;
+typedef struct JACOBIAN JACOBIAN;
+
+typedef int (*jacobianColumn_func_ptr)(DATA* data, threadData_t* threadData, JACOBIAN* thisJacobian, JACOBIAN* parentJacobian);
+typedef int (*initialAnalyticalJacobian_func_ptr)(DATA* data, threadData_t* threadData, JACOBIAN* jacobian);
 
 /* Model info structures */
 typedef struct VAR_INFO
 {
-  int id;
-  int inputIndex; /* -1 means not an input */
+  int id;               /* -1 if no value reference set */
+  int inputIndex;       /* -1 means not an input */
   const char *name;
   const char *comment;
   FILE_INFO info;
@@ -186,19 +189,20 @@ typedef struct NONLINEAR_PATTERN
  * @brief Analytic jacobian struct
  *
  */
-typedef struct ANALYTIC_JACOBIAN
+typedef struct JACOBIAN
 {
-  JACOBIAN_AVAILABILITY availability;  /* Availability status */
-  unsigned int sizeCols;               /* Number of columns of Jacobian */
-  unsigned int sizeRows;               /* Number of rows of Jacobian */
-  unsigned int sizeTmpVars;            /* Length of vector tmpVars */
-  SPARSE_PATTERN* sparsePattern;       /* Contain sparse pattern including coloring */
-  modelica_real* seedVars;             /* Seed vector for specifying which columns to evaluate */
-  modelica_real* tmpVars;
-  modelica_real* resultVars;           /* Result column for given seed vector */
-  modelica_real dae_cj;                /* Is the scalar in the system Jacobian, proportional to the inverse of the step size. From User Documentation for ida v5.4.0 equation (2.5). */
-  int (*constantEqns)(void* data, threadData_t *threadData, void* thisJacobian, void* parentJacobian);  /* Constant equations independent of seed vector */
-} ANALYTIC_JACOBIAN;
+  JACOBIAN_AVAILABILITY availability;   /* Availability status */
+  size_t sizeCols;                      /* Number of columns of Jacobian */
+  size_t sizeRows;                      /* Number of rows of Jacobian */
+  size_t sizeTmpVars;                   /* Length of vector tmpVars */
+  SPARSE_PATTERN* sparsePattern;        /* Contain sparse pattern including coloring */
+  modelica_real* seedVars;              /* Seed vector for specifying which columns to evaluate */
+  modelica_real* tmpVars;               /* Partial derivatives used to compute resultVars */
+  modelica_real* resultVars;            /* Result column for given seed vector */
+  modelica_real dae_cj;                 /* Is the scalar in the system Jacobian, proportional to the inverse of the step size. From User Documentation for ida v5.4.0 equation (2.5). */
+  jacobianColumn_func_ptr evalColumn;   /* symbolic jacobian column based on seed vector */
+  jacobianColumn_func_ptr constantEqns; /* Constant equations independent of seed vector */
+} JACOBIAN;
 
 /* EXTERNAL_INPUT
  *
@@ -215,12 +219,31 @@ typedef struct EXTERNAL_INPUT
   modelica_integer i;
 } EXTERNAL_INPUT;
 
+/**
+ * @brief Specifies homotopy method
+ *
+ */
+typedef enum HOMOTOPY_METHOD
+{
+  LOCAL_EQUIDISTANT_HOMOTOPY = 0,   // 0: local homotopy (equidistant lambda)
+  GLOBAL_EQUIDISTANT_HOMOTOPY = 1,  // 1: global homotopy (equidistant lambda)
+  GLOBAL_ADAPTIVE_HOMOTOPY = 2,     // 2: new global homotopy approach (adaptive lambda)
+  LOCAL_ADAPTIVE_HOMOTOPY = 3,      // 3: new local homotopy approach (adaptive lambda)
+  NO_HOMOTOPY = 4                   // 4: no homotopy / else
+} HOMOTOPY_METHOD;
+
+enum ALIAS_TYPE {
+  ALIAS_TYPE_VARIABLE = 0,
+  ALIAS_TYPE_PARAMETER = 1,
+  ALIAS_TYPE_TIME = 2,
+};
+
 /* Alias data with various types */
 typedef struct DATA_ALIAS
 {
   int negate;
   int nameID;                          /* pointer to Alias */
-  char aliasType;                      /* 0 variable, 1 parameter, 2 time */
+  enum ALIAS_TYPE aliasType;           /* 0 variable, 1 parameter, 2 time */
   VAR_INFO info;
   modelica_boolean filterOutput;       /* true if this variable should be filtered */
 } DATA_ALIAS;
@@ -230,6 +253,13 @@ typedef DATA_ALIAS DATA_INTEGER_ALIAS;
 typedef DATA_ALIAS DATA_BOOLEAN_ALIAS;
 typedef DATA_ALIAS DATA_STRING_ALIAS;
 
+enum var_type {
+  T_REAL,     /* Variable is of real type */
+  T_INTEGER,  /* Variable is of integer type */
+  T_BOOLEAN,  /* Variable is of boolean type */
+  T_STRING    /* Variable is of string type */
+};
+
 /* collect all attributes from one variable in one struct */
 typedef struct REAL_ATTRIBUTE
 {
@@ -240,7 +270,7 @@ typedef struct REAL_ATTRIBUTE
   modelica_boolean fixed;              /* depends on the type */
   modelica_boolean useNominal;         /* = false */
   modelica_real nominal;               /* = 1.0 */
-  modelica_real start;                 /* = 0.0 */
+  real_array start;                    /* = 0.0 */
 } REAL_ATTRIBUTE;
 
 typedef struct INTEGER_ATTRIBUTE
@@ -262,8 +292,33 @@ typedef struct STRING_ATTRIBUTE
   modelica_string start;               /* = "" */
 } STRING_ATTRIBUTE;
 
+/* Model dimension structures */
+enum DIMENSION_ATTRIBUTE_TYPE{
+  DIMENSION_BY_START = 0,               /* dimension defined by start */
+  DIMENSION_BY_VALUE_REFERENCE = 1      /* dimension defined by value reference of structural parameter */
+};
+
+typedef struct DIMENSION_ATTRIBUTE
+{
+  /** How the dimension is defined */
+  enum DIMENSION_ATTRIBUTE_TYPE type;
+  /** If `type` is `DIMENSION_BY_START`: Dimension
+    * If `type` is `DIMENSION_BY_VALUE_REFERENCE`: Will be set to start value of referenced variable in function `calculateLength`. */
+  modelica_integer start;
+  /** If `type` is `DIMENSION_BY_VALUE_REFERENCE`: Value reference of structural parameter specifying dimension. */
+  modelica_integer valueReference;
+} DIMENSION_ATTRIBUTE;
+
+typedef struct DIMENSION_INFO
+{
+  size_t numberOfDimensions;            /* Number of dimension tags <dimension>, scalar if equal to 0. */
+  DIMENSION_ATTRIBUTE* dimensions;      /* Array of dimension sizes */
+  size_t scalar_length;                 /* Length of variable after scalarization to 1-dimensional array */
+} DIMENSION_INFO;
+
 typedef struct STATIC_REAL_DATA
 {
+  DIMENSION_INFO dimension;
   VAR_INFO info;
   REAL_ATTRIBUTE attribute;
   modelica_boolean filterOutput;       /* true if this variable should be filtered */
@@ -272,6 +327,7 @@ typedef struct STATIC_REAL_DATA
 
 typedef struct STATIC_INTEGER_DATA
 {
+  DIMENSION_INFO dimension;
   VAR_INFO info;
   INTEGER_ATTRIBUTE attribute;
   modelica_boolean filterOutput;       /* true if this variable should be filtered */
@@ -280,6 +336,7 @@ typedef struct STATIC_INTEGER_DATA
 
 typedef struct STATIC_BOOLEAN_DATA
 {
+  DIMENSION_INFO dimension;
   VAR_INFO info;
   BOOLEAN_ATTRIBUTE attribute;
   modelica_boolean filterOutput;       /* true if this variable should be filtered */
@@ -288,15 +345,13 @@ typedef struct STATIC_BOOLEAN_DATA
 
 typedef struct STATIC_STRING_DATA
 {
+  DIMENSION_INFO dimension;
   VAR_INFO info;
   STRING_ATTRIBUTE attribute;
   modelica_boolean filterOutput;       /* true if this variable should be filtered */
   modelica_boolean time_unvarying;     /* true if the value is only computed once during initialization */
 } STATIC_STRING_DATA;
 
-typedef int (*analyticalJacobianColumn_func_ptr)(DATA* data, threadData_t* threadData, ANALYTIC_JACOBIAN* thisJacobian, ANALYTIC_JACOBIAN* parentJacobian);
-typedef int (*initialAnalyticalJacobian_func_ptr)(DATA* data, threadData_t* threadData, ANALYTIC_JACOBIAN* jacobian);
-
 /**
  * @brief User data provided to residual functions.
  *
@@ -333,11 +388,11 @@ typedef struct NONLINEAR_SYSTEM_DATA
 
   /* if analyticalJacobianColumn != NULL analyticalJacobian is available and
    * can be produced with the help of analyticalJacobianColumnn function pointer
-   * which is a generic column of the jacobian matrix. (see ANALYTIC_JACOBIAN)
+   * which is a generic column of the jacobian matrix. (see JACOBIAN)
    *
    * if analyticalJacobianColumn == NULL no analyticalJacobian is available
    */
-  analyticalJacobianColumn_func_ptr analyticalJacobianColumn;
+  jacobianColumn_func_ptr analyticalJacobianColumn;
   initialAnalyticalJacobian_func_ptr initialAnalyticalJacobian;
   modelica_integer jacobianIndex;
 
@@ -345,6 +400,7 @@ typedef struct NONLINEAR_SYSTEM_DATA
   modelica_boolean isPatternAvailable;
   NONLINEAR_PATTERN *nonlinearPattern;
   int *eqn_simcode_indices;
+  modelica_integer torn_plus_residual_size;
 
   void (*residualFunc)(RESIDUAL_USERDATA* userData, const double* x, double* res, const int* flag);
   int (*residualFuncConstraints)(RESIDUAL_USERDATA* userData, const double*, double*, const int*);
@@ -396,8 +452,8 @@ typedef struct LINEAR_SYSTEM_THREAD_DATA
   modelica_real *A;                    /* matrix A */
   modelica_real *b;                    /* vector b */
 
-  ANALYTIC_JACOBIAN* parentJacobian;   /* if != NULL then it's the parent jacobian matrix */
-  ANALYTIC_JACOBIAN* jacobian;         /* jacobian */
+  JACOBIAN* parentJacobian;            /* if != NULL then it's the parent jacobian matrix */
+  JACOBIAN* jacobian;                  /* jacobian */
 
   /* Statistics for each thread */
   unsigned long numberOfCall;          /* number of solving calls of this system */
@@ -418,7 +474,7 @@ typedef struct LINEAR_SYSTEM_DATA
   void (*setAElement)(int row, int col, double value, int nth, LINEAR_SYSTEM_DATA* linearSystemData, threadData_t* threadData);
   void (*setBElement)(int row, double value, LINEAR_SYSTEM_DATA* linearSystemData, threadData_t* threadData);
 
-  analyticalJacobianColumn_func_ptr analyticalJacobianColumn;
+  jacobianColumn_func_ptr analyticalJacobianColumn;
   initialAnalyticalJacobian_func_ptr initialAnalyticalJacobian;
 
   void (*residualFunc)(RESIDUAL_USERDATA* userData, const double* x, double* res, const int* flag);
@@ -505,11 +561,11 @@ typedef struct STATE_SET_DATA
 
   /* if analyticalJacobianColumn != NULL analyticalJacobian is available and
    * can be produced with the help of analyticalJacobianColumnn function pointer
-   * which is a generic column of the jacobian matrix. (see ANALYTIC_JACOBIAN)
+   * which is a generic column of the jacobian matrix. (see JACOBIAN)
    *
    * if analyticalJacobianColumn == NULL no analyticalJacobian is available
    */
-  analyticalJacobianColumn_func_ptr analyticalJacobianColumn;
+  jacobianColumn_func_ptr analyticalJacobianColumn;
   initialAnalyticalJacobian_func_ptr initialAnalyticalJacobian;
   modelica_integer jacobianIndex;
 } STATE_SET_DATA;
@@ -587,25 +643,44 @@ typedef struct MODEL_DATA
 
   long nBaseClocks;                    /* total number of base-clocks*/
 
-  fortran_integer nStates;
+  /* Number of un-scalrarized variables (arrays count as one variable) */
+  long nStatesArray;            /* Number of array + scalar state variables */
+  long nVariablesRealArray;     /* Number of array + scalar real variables: states + state derivatives + real algebraic variables */
+  long nVariablesIntegerArray;  /* Number of array + scalar integer variables */
+  long nVariablesBooleanArray;  /* Number of array + scalar boolean variables */
+  long nVariablesStringArray;   /* Number of array + scalar string variables */
 
-  /* numbers of unscalarized variables (arrays counted as one variable, used for index map) */
-  size_t nVariablesRealArray;
-  size_t nVariablesIntegerArray;
-  size_t nVariablesBooleanArray;
-  size_t nVariablesStringArray;
+  long nParametersRealArray;    /* Number of array + scalar real parameters */
+  long nParametersIntegerArray; /* Number of array + scalar integer parameters */
+  long nParametersBooleanArray; /* Number of array + scalar boolean parameters */
+  long nParametersStringArray;  /* Number of array + scalar string parameters */
 
-  long nVariablesReal;                 /* all Real Variables of the model (states, statesderivatives, algebraics, real discretes) */
-  long nDiscreteReal;                  /* only all _discrete_ reals */
-  long nVariablesInteger;
-  long nVariablesBoolean;
-  long nVariablesString;
-  long nParametersReal;
-  long nParametersInteger;
-  long nParametersBoolean;
-  long nParametersString;
-  long nInputVars;
-  long nOutputVars;
+  long nAliasRealArray;         /* Number of array + scalar real alias variables */
+  long nAliasIntegerArray;      /* Number of array + scalar integer alias variables */
+  long nAliasBooleanArray;      /* Number of array + scalar boolean alias variables */
+  long nAliasStringArray;       /* Number of array + scalar string alias variables */
+  // TODO: array handling for input and output vars missing
+
+  /* Number of scalarized variables (arrays are flatten to scalar elements.) */
+  long nStates;                 /* Number of state variables*/
+  long nVariablesReal;          /* Number of real variables: states + state derivatives + real algebraic variables + real discrete variables */
+  long nDiscreteReal;           /* Number of all discrete real variables */
+  long nVariablesInteger;       /* Number of integer variables */
+  long nVariablesBoolean;       /* Number of boolean variables */
+  long nVariablesString;        /* Number of string variables */
+
+  long nParametersReal;         /* Number of real parameters */
+  long nParametersInteger;      /* Number of integer parameters */
+  long nParametersBoolean;      /* Number of boolean parameters */
+  long nParametersString;       /* Number of string parameters */
+
+  long nInputVars;              /* Number of input variables */
+  long nOutputVars;             /* Number of output variables */
+
+  long nAliasReal;              /* Number of real alias variables */
+  long nAliasInteger;           /* Number of integer alias variables */
+  long nAliasBoolean;           /* Number of boolean alias variables */
+  long nAliasString;            /* Number of string alias variables */
 
   long nZeroCrossings;
   long nRelations;
@@ -621,11 +696,6 @@ typedef struct MODEL_DATA
   long nOptimizeConstraints;           /* number of additional variables for constraint in dynamic optimization */
   long nOptimizeFinalConstraints;      /* number of additional variables for final constraint in dynamic optimization */
 
-  long nAliasReal;
-  long nAliasInteger;
-  long nAliasBoolean;
-  long nAliasString;
-
   long nJacobians;
 
   long nSensitivityVars;
@@ -780,12 +850,22 @@ typedef struct SIMULATION_INFO
   modelica_real* states_left;          /* work array for findRoot in event.c */
   modelica_real* states_right;         /* work array for findRoot in event.c */
 
-  /* index map: arr_idx -> start_idx */
+  /* Index maps: arr_idx -> start_idx */
   size_t* realVarsIndex;
   size_t* integerVarsIndex;
   size_t* booleanVarsIndex;
   size_t* stringVarsIndex;
 
+  size_t* realParamsIndex;
+  size_t* integerParamsIndex;
+  size_t* booleanParamsIndex;
+  size_t* stringParamsIndex;
+
+  size_t* realAliasIndex;
+  size_t* integerAliasIndex;
+  size_t* booleanAliasIndex;
+  size_t* stringAliasIndex;
+
   /* old vars for event handling */
   modelica_real timeValueOld;
   modelica_real* realVarsOld;
@@ -814,7 +894,7 @@ typedef struct SIMULATION_INFO
   modelica_real* sensitivityMatrix;    /* used by integrator for sensitivity mode */
   int* sensitivityParList;             /* used by integrator for sensitivity mode */
 
-  ANALYTIC_JACOBIAN* analyticJacobians; // TODO Only store information for Jacobian used by integrator here
+  JACOBIAN* analyticJacobians;          // TODO Only store information for Jacobian used by integrator here
 
   NONLINEAR_SYSTEM_DATA* nonlinearSystemData; /* Array of non-linear systems */
 
