@@ -75,9 +75,6 @@ void omc_assert_warning_function(FILE_INFO info,  const char *msg, ...);
 void omc_terminate_function(FILE_INFO info, const char *msg, ...);
 void omc_throw_function(threadData_t*) __attribute__ ((noreturn));
 
-/* #define USE_DEBUG_OUTPUT */
-/* #define USE_DEBUG_TRACE */
-
 enum OMC_LOG_STREAM
 {
   OMC_LOG_UNKNOWN = 0,
@@ -112,12 +109,17 @@ enum OMC_LOG_STREAM
   OMC_LOG_LS,
   OMC_LOG_LS_V,
   OMC_LOG_MIXED,
+  OMC_LOG_MOO,
   OMC_LOG_NLS,
   OMC_LOG_NLS_V,
   OMC_LOG_NLS_HOMOTOPY,
   OMC_LOG_NLS_JAC,
   OMC_LOG_NLS_JAC_TEST,
+  OMC_LOG_NLS_JAC_SUMS,
   OMC_LOG_NLS_NEWTON_DIAGNOSTICS,
+  OMC_LOG_NLS_DERIVATIVE_TEST,
+  OMC_LOG_NLS_SVD,
+  OMC_LOG_NLS_SVD_V,
   OMC_LOG_NLS_RES,
   OMC_LOG_NLS_EXTRAPOLATE,
   OMC_LOG_RES_INIT,
@@ -132,9 +134,6 @@ enum OMC_LOG_STREAM
   OMC_LOG_STATS_V,
   OMC_LOG_SUCCESS,
   OMC_LOG_SYNCHRONOUS,
-#ifdef USE_DEBUG_TRACE
-  OMC_LOG_TRACE,
-#endif
   OMC_LOG_ZEROCROSSINGS,
 
   OMC_SIM_LOG_MAX
@@ -163,22 +162,6 @@ extern int omc_showAllWarnings;
 #define OMC_ACTIVE_STREAM(stream)    (omc_useStream[stream])
 #define OMC_ACTIVE_WARNING_STREAM(stream)    (omc_showAllWarnings || omc_useStream[stream])
 
-#ifdef USE_DEBUG_OUTPUT
-  #define OMC_DEBUG_STREAM(stream)    (omc_useStream[stream])
-#else
-  #define OMC_DEBUG_STREAM(stream)    (0)
-#endif
-
-#ifdef USE_DEBUG_TRACE
-  extern int DEBUG_TRACE_PUSH_HELPER(const char* pFnc, const char* pFile, const long ln);
-  extern int DEBUG_TRACE_POP_HELPER(int traceID);
-  #define TRACE_PUSH int __DEBUG_TRACE_HANDLE = DEBUG_TRACE_PUSH_HELPER(__FUNCTION__, __FILE__, __LINE__);
-  #define TRACE_POP DEBUG_TRACE_POP_HELPER(__DEBUG_TRACE_HANDLE);
-#else
-  #define TRACE_PUSH
-  #define TRACE_POP
-#endif
-
 extern void (*messageFunction)(int type, int stream, FILE_INFO info, int indentNext, char *msg, int subline, const int *indexes);
 extern void (*messageClose)(int stream);
 extern void (*messageCloseWarning)(int stream);
@@ -240,16 +223,6 @@ static void OMC_INLINE assertStreamPrint(threadData_t *threadData, int cond, con
     exit(1); \
   }
 
-#ifdef USE_DEBUG_OUTPUT
-void debugStreamPrint(int stream, FILE_INFO info, int indentNext, const char *format, ...) __attribute__ ((format (printf, 3, 4)));
-void debugStreamPrintWithEquationIndexes(int stream, FILE_INFO info, int indentNext, const int *indexes, const char *format, ...) __attribute__ ((format (printf, 5, 6)));
-#else
-static OMC_INLINE void debugStreamPrint(int stream __attribute__((unused)), int indentNext __attribute__((unused)), const char *format __attribute__((unused)), ...) __attribute__ ((format (printf, 3, 4)));
-static OMC_INLINE void debugStreamPrint(int stream __attribute__((unused)), int indentNext __attribute__((unused)), const char *format __attribute__((unused)), ...) {/* Do nothing */}
-static OMC_INLINE void debugStreamPrintWithEquationIndexes(int stream __attribute__((unused)), FILE_INFO info, int indentNext __attribute__((unused)), const int *indexes __attribute__((unused)), const char *format __attribute__((unused)), ...) __attribute__ ((format (printf, 5, 6)));
-static OMC_INLINE void debugStreamPrintWithEquationIndexes(int stream  __attribute__((unused)), FILE_INFO info __attribute__((unused)), int indentNext __attribute__((unused)), const int *indexes __attribute__((unused)), const char *format __attribute__((unused)), ...)  {/* Do nothing */}
-#endif
-
 #ifdef __cplusplus
 }
 #endif
