@@ -134,7 +134,7 @@ int omc_fclose(FILE* stream)
  * @param size              Size in bytes of each element to read.
  * @param count             Number of elements to read, each with size `size` bytes.
  * @param stream            Pointer to FILE object with input stream.
- * @param allow_early_eof   Specifies wheather the call is okay or not with reaching
+ * @param allow_early_eof   Specifies whether the call is okay or not with reaching
  *                          EOF before reading the specified amount. Set it to 1 if you do not exactly know how much to read
  *                          and would not mind if the file ends before 'count' elements are read from it.
  *                          If you are not sure what to do start by passing 0.
@@ -145,7 +145,7 @@ size_t omc_fread(void *buffer, size_t size, size_t count, FILE *stream, int allo
   if(read_len != count)  {
     if (feof(stream) && !allow_early_eof) {
       fprintf(stderr, "Error reading stream: unexpected end of file.\n");
-      fprintf(stderr, "Expected to read %zu. Read only %zu\n", count, read_len);
+      fprintf(stderr, "Expected to read %zu. Read only %zu.\n", count, read_len);
     }
     else if (ferror(stream)) {
       fprintf(stderr, "Error: omc_fread() failed to read file.\n");
