@@ -50,13 +50,14 @@
 OPC_UA_EXPORT void* omc_embedded_server_init(DATA *data, double t, double step, const char *argv_0, void (*omc_real_time_sync_update)(DATA *data, double scaling), int port);
 OPC_UA_EXPORT void omc_wait_for_step(void*);
 OPC_UA_EXPORT void omc_embedded_server_deinit(void*);
-OPC_UA_EXPORT int omc_embedded_server_update(void*, double t);
+OPC_UA_EXPORT int omc_embedded_server_update(void*, double t, int*);
 
 #define OMC_OPC_NODEID_STEP 10000
 #define OMC_OPC_NODEID_RUN  10001
 #define OMC_OPC_NODEID_REAL_TIME_SCALING_FACTOR 10002
 #define OMC_OPC_NODEID_ENABLE_STOP_TIME 10003
 #define OMC_OPC_NODEID_TIME 10004
+#define OMC_OPC_NODEID_TERMINATE 10005
 
 #define MAX_VARS_KIND 100000000
 #define ALIAS_START_ID (MAX_VARS_KIND/2)
