@@ -72,8 +72,7 @@ TVariablesTreeItem::TVariablesTreeItem(const QVector<QVariant> &tVariableItemDat
 
 TVariablesTreeItem::~TVariablesTreeItem()
 {
-  qDeleteAll(mChildren);
-  mChildren.clear();
+  removeChildren();
 }
 
 void TVariablesTreeItem::insertChild(int position, TVariablesTreeItem *pTVariablesTreeItem)
@@ -92,11 +91,6 @@ void TVariablesTreeItem::removeChildren()
   mChildren.clear();
 }
 
-void TVariablesTreeItem::removeChild(TVariablesTreeItem *pTVariablesTreeItem)
-{
-  mChildren.removeOne(pTVariablesTreeItem);
-}
-
 int TVariablesTreeItem::columnCount() const
 {
   return 4;
@@ -184,14 +178,16 @@ int TVariablesTreeModel::columnCount(const QModelIndex &parent) const
 int TVariablesTreeModel::rowCount(const QModelIndex &parent) const
 {
   TVariablesTreeItem *pParentTVariablesTreeItem;
-  if (parent.column() > 0)
+  if (parent.column() > 0) {
     return 0;
+  }
 
-  if (!parent.isValid())
+  if (!parent.isValid()) {
     pParentTVariablesTreeItem = mpRootTVariablesTreeItem;
-  else
+  } else {
     pParentTVariablesTreeItem = static_cast<TVariablesTreeItem*>(parent.internalPointer());
-  return pParentTVariablesTreeItem->getChildren().size();
+  }
+  return pParentTVariablesTreeItem ? pParentTVariablesTreeItem->childrenSize() : 0;
 }
 
 QVariant TVariablesTreeModel::headerData(int section, Qt::Orientation orientation, int role) const
@@ -203,21 +199,22 @@ QVariant TVariablesTreeModel::headerData(int section, Qt::Orientation orientatio
 
 QModelIndex TVariablesTreeModel::index(int row, int column, const QModelIndex &parent) const
 {
-  if (!hasIndex(row, column, parent))
+  if (!hasIndex(row, column, parent)) {
     return QModelIndex();
+  }
 
   TVariablesTreeItem *pParentTVariablesTreeItem;
-
-  if (!parent.isValid())
+  if (!parent.isValid()) {
     pParentTVariablesTreeItem = mpRootTVariablesTreeItem;
-  else
+  } else {
     pParentTVariablesTreeItem = static_cast<TVariablesTreeItem*>(parent.internalPointer());
+  }
 
-  TVariablesTreeItem *pChildTVariablesTreeItem = pParentTVariablesTreeItem->child(row);
-  if (pChildTVariablesTreeItem)
-    return createIndex(row, column, pChildTVariablesTreeItem);
-  else
+  if (row < 0 || row >= pParentTVariablesTreeItem->childrenSize()) {
     return QModelIndex();
+  }
+
+  return createIndex(row, column, pParentTVariablesTreeItem->child(row));
 }
 
 QModelIndex TVariablesTreeModel::parent(const QModelIndex &index) const
@@ -251,7 +248,7 @@ Qt::ItemFlags TVariablesTreeModel::flags(const QModelIndex &index) const
   /* Ticket #3207. Make all the items enable and selectable.
    */
 //  TVariablesTreeItem *pTVariablesTreeItem = static_cast<TVariablesTreeItem*>(index.internalPointer());
-//  if (pTVariablesTreeItem && pTVariablesTreeItem->getChildren().size() == 0)
+//  if (pTVariablesTreeItem && pTVariablesTreeItem->childrenSize() == 0)
 //    flags |= Qt::ItemIsEnabled | Qt::ItemIsSelectable;
 
   return flags;
@@ -261,7 +258,7 @@ TVariablesTreeItem* TVariablesTreeModel::findTVariablesTreeItem(const QString &n
 {
   if (root->getVariableName() == name)
     return root;
-  for (int i = root->getChildren().size(); --i >= 0; )
+  for (int i = root->childrenSize(); --i >= 0; )
     if (TVariablesTreeItem *item = findTVariablesTreeItem(name, root->getChildren().at(i)))
       return item;
   return 0;
@@ -269,7 +266,11 @@ TVariablesTreeItem* TVariablesTreeModel::findTVariablesTreeItem(const QString &n
 
 QModelIndex TVariablesTreeModel::tVariablesTreeItemIndex(const TVariablesTreeItem *pTVariablesTreeItem) const
 {
-  return tVariablesTreeItemIndexHelper(pTVariablesTreeItem, mpRootTVariablesTreeItem, QModelIndex());
+  if (!pTVariablesTreeItem || pTVariablesTreeItem == mpRootTVariablesTreeItem) {
+    return QModelIndex();
+  }
+
+  return createIndex(pTVariablesTreeItem->row(), 0, const_cast<TVariablesTreeItem *>(pTVariablesTreeItem));
 }
 
 void TVariablesTreeModel::insertTVariablesItems(QHashIterator<QString, OMVariable> variables)
@@ -406,32 +407,14 @@ void TVariablesTreeModel::insertTVariablesItems(QHashIterator<QString, OMVariabl
 
 void TVariablesTreeModel::clearTVariablesTreeItems()
 {
-  const int n = mpRootTVariablesTreeItem->getChildren().size();
+  const int n = mpRootTVariablesTreeItem->childrenSize();
   if (n > 0) {
-    QModelIndex index = tVariablesTreeItemIndex(mpRootTVariablesTreeItem);
-    beginRemoveRows(index, 0, n - 1);
+    beginRemoveRows(tVariablesTreeItemIndex(mpRootTVariablesTreeItem), 0, n - 1);
     mpRootTVariablesTreeItem->removeChildren();
     endRemoveRows();
   }
 }
 
-QModelIndex TVariablesTreeModel::tVariablesTreeItemIndexHelper(const TVariablesTreeItem *pTVariablesTreeItem, const TVariablesTreeItem *pParentTVariablesTreeItem,
-                                                               const QModelIndex &parentIndex) const
-{
-  if (pTVariablesTreeItem == pParentTVariablesTreeItem) {
-    return parentIndex;
-  }
-  for (int i = pParentTVariablesTreeItem->getChildren().size(); --i >= 0; ) {
-    const TVariablesTreeItem *childItem = pParentTVariablesTreeItem->getChildren().at(i);
-    QModelIndex childIndex = index(i, 0, parentIndex);
-    QModelIndex index = tVariablesTreeItemIndexHelper(pTVariablesTreeItem, childItem, childIndex);
-    if (index.isValid()) {
-      return index;
-    }
-  }
-  return QModelIndex();
-}
-
 /*!
  * \brief TVariablesTreeModel::insertVariablesItems
  * Creates TVariablesTreeItem using VariableNode and adds them to the TVariablesTreeView.
@@ -552,16 +535,16 @@ EquationTreeWidget::EquationTreeWidget(TransformationsWidget *pTransformationWid
   connect(this, SIGNAL(itemDoubleClicked(QTreeWidgetItem*,int)), mpTransformationWidget, SLOT(fetchEquationData(QTreeWidgetItem*,int)));
 }
 
-TransformationsWidget::TransformationsWidget(QString infoJSONFullFileName, bool profiling, QWidget *pParent)
-  : QWidget(pParent), mInfoJSONFullFileName(infoJSONFullFileName)
+/*!
+ * \brief TransformationsWidget::TransformationsWidget
+ * \param infoJSONFullFileName - model_info.json file path
+ * \param profiling - is profiling enabled
+ * \param checkForProfilingFiles - check if profiling files exists
+ * \param pParent
+ */
+TransformationsWidget::TransformationsWidget(QString infoJSONFullFileName, bool profiling, bool checkForProfilingFiles, QWidget *pParent)
+  : QWidget(pParent), mInfoJSONFullFileName(infoJSONFullFileName), mProfilingEnabled(profiling), mCheckForProfilingFiles(checkForProfilingFiles)
 {
-  if (!mInfoJSONFullFileName.endsWith("_info.json") || !profiling) {
-    mProfJSONFullFileName = "";
-    mProfilingDataRealFileName = "";
-  } else {
-    mProfJSONFullFileName = infoJSONFullFileName.left(infoJSONFullFileName.size() - 9) + "prof.json";
-    mProfilingDataRealFileName = infoJSONFullFileName.left(infoJSONFullFileName.size() - 9) + "prof.realdata";
-  }
   mCurrentEquationIndex = 0;
   setWindowIcon(QIcon(":/Resources/icons/equational-debugger.svg"));
   setWindowTitle(QString(Helper::applicationName).append(" - ").append(Helper::transformationalDebugger));
@@ -569,7 +552,7 @@ TransformationsWidget::TransformationsWidget(QString infoJSONFullFileName, bool
   pReloadToolButton->setToolTip(Helper::reload);
   pReloadToolButton->setAutoRaise(true);
   pReloadToolButton->setIcon(QIcon(":/Resources/icons/refresh.svg"));
-  connect(pReloadToolButton, SIGNAL(clicked()), SLOT(reloadTransformations()));
+  connect(pReloadToolButton, SIGNAL(clicked()), SLOT(loadTransformations()));
   /* info xml file path label */
   Label *pInfoXMLFilePathLabel = new Label(mInfoJSONFullFileName, this);
   pInfoXMLFilePathLabel->setElideMode(Qt::ElideMiddle);
@@ -901,8 +884,170 @@ static OMEquation* getOMEquation(QList<OMEquation*> equations, int index)
   return NULL;
 }
 
+/*!
+ * \brief TransformationsWidget::loadTransformations
+ * \param profiling - is profiling enabled
+ * \param checkForProfilingFiles - check if profiling files exists
+ */
+void TransformationsWidget::loadTransformations(bool profiling, bool checkForProfilingFiles)
+{
+  mProfilingEnabled = profiling;
+  mCheckForProfilingFiles = checkForProfilingFiles;
+  loadTransformations();
+}
+
+void TransformationsWidget::fetchDefinedInEquations(const OMVariable &variable)
+{
+  /* Clear the defined in tree. */
+  clearTreeWidgetItems(mpDefinedInEquationsTreeWidget);
+  /* add defined in equations */
+  for (int i=0; i<variable.definedIn.size(); i++) {
+    OMEquation *equation = getOMEquation(mEquations, variable.definedIn[i]);
+    if (equation) {
+      QStringList values;
+      values << QString::number(variable.definedIn[i]) << equation->section << equation->toString();
+      QTreeWidgetItem *pDefinedInTreeItem = new IntegerTreeWidgetItem(values, mpDefinedInEquationsTreeWidget);
+      pDefinedInTreeItem->setToolTip(0, values[0]);
+      pDefinedInTreeItem->setToolTip(1, values[1]);
+      pDefinedInTreeItem->setToolTip(2, values[2]);
+      mpDefinedInEquationsTreeWidget->addTopLevelItem(pDefinedInTreeItem);
+    }
+  }
+}
+
+void TransformationsWidget::fetchUsedInEquations(const OMVariable &variable)
+{
+  /* Clear the used in tree. */
+  clearTreeWidgetItems(mpUsedInEquationsTreeWidget);
+  /* add used in equations */
+  foreach (int index, variable.usedIn) {
+    OMEquation *equation = getOMEquation(mEquations, index);
+    if (equation) {
+      QStringList values;
+      values << QString::number(index) << equation->section << equation->toString();
+      QTreeWidgetItem *pUsedInTreeItem = new IntegerTreeWidgetItem(values, mpUsedInEquationsTreeWidget);
+      pUsedInTreeItem->setToolTip(0, values[0]);
+      pUsedInTreeItem->setToolTip(1, values[1]);
+      pUsedInTreeItem->setToolTip(2, values[2]);
+      mpUsedInEquationsTreeWidget->addTopLevelItem(pUsedInTreeItem);
+    }
+  }
+}
+
+void TransformationsWidget::fetchOperations(const OMVariable &variable)
+{
+  /* Clear the operations tree. */
+  clearTreeWidgetItems(mpVariableOperationsTreeWidget);
+  /* add operations */
+  if (hasOperationsEnabled) {
+    foreach (OMOperation *op, variable.ops) {
+      QTreeWidgetItem *pOperationTreeItem = new QTreeWidgetItem();
+      mpVariableOperationsTreeWidget->addTopLevelItem(pOperationTreeItem);
+      // set label item
+      Label *opText = new Label("<html><div style=\"margin:3px;\">" + op->toHtml() + "</div></html>");
+      mpVariableOperationsTreeWidget->setItemWidget(pOperationTreeItem, 0, opText);
+    }
+  } else {
+    QString message = GUIMessages::getMessage(GUIMessages::SET_INFO_XML_FLAG).arg(Helper::toolsOptionsPath);
+    QStringList values;
+    values << message;
+    QString toolTip = message;
+    QTreeWidgetItem *pOperationTreeItem = new QTreeWidgetItem(values);
+    pOperationTreeItem->setToolTip(0, toolTip);
+    mpVariableOperationsTreeWidget->addTopLevelItem(pOperationTreeItem);
+  }
+  mpVariableOperationsTreeWidget->resizeColumnToContents(0);
+}
+
+QTreeWidgetItem* TransformationsWidget::makeEquationTreeWidgetItem(int equationIndex, int allowChild)
+{
+  OMEquation *equation = mEquations[equationIndex];
+  if (!allowChild && equation->parent) {
+    return NULL; // Only output equations in one position
+  }
+  QStringList values;
+  values << QString::number(equation->index)
+         << equation->section
+         << equation->toString();
+  if (equation->profileBlock >= 0) {
+    values << QString::number(equation->ncall)
+         << QString::number(equation->maxTime, 'g', 3)
+         << QString::number(equation->time, 'g', 3)
+         << QString::number(100 * equation->fraction, 'g', 3) + "%";
+  }
+
+  QTreeWidgetItem *pEquationTreeItem = new IntegerTreeWidgetItem(values, mpEquationsTreeWidget);
+  pEquationTreeItem->setToolTip(0, values[0]);
+  pEquationTreeItem->setToolTip(1, values[1]);
+  pEquationTreeItem->setToolTip(2, "<html><div style=\"margin:3px;\">" +
+  QString(values[2]).toHtmlEscaped()
+  + "</div></html>");
+  pEquationTreeItem->setToolTip(4, "Maximum execution time in a single step");
+  pEquationTreeItem->setToolTip(5, "Total time excluding the overhead of measuring.");
+  pEquationTreeItem->setToolTip(6, "Fraction of time, 100% is the total time of all non-child equations.");
+  return pEquationTreeItem;
+}
+
+/*!
+ * \brief TransformationsWidget::loadTransformations
+ * Loads the transformations from the model_info.json file.
+ */
 void TransformationsWidget::loadTransformations()
 {
+  mCurrentEquationIndex = 0;
+  /* clear trees */
+  mpTVariablesTreeModel->clearTVariablesTreeItems();
+  /* Clear the defined in tree. */
+  clearTreeWidgetItems(mpDefinedInEquationsTreeWidget);
+  /* Clear the used in tree. */
+  clearTreeWidgetItems(mpUsedInEquationsTreeWidget);
+  /* Clear the variable operations tree. */
+  clearTreeWidgetItems(mpVariableOperationsTreeWidget);
+  /* clear the variable tree filters. */
+  bool signalsState = mpTreeSearchFilters->getFilterTextBox()->blockSignals(true);
+  mpTreeSearchFilters->getFilterTextBox()->clear();
+  mpTreeSearchFilters->getFilterTextBox()->blockSignals(signalsState);
+  signalsState = mpTreeSearchFilters->getSyntaxComboBox()->blockSignals(true);
+  mpTreeSearchFilters->getSyntaxComboBox()->setCurrentIndex(0);
+  mpTreeSearchFilters->getSyntaxComboBox()->blockSignals(signalsState);
+  signalsState = mpTreeSearchFilters->getCaseSensitiveCheckBox()->blockSignals(true);
+  mpTreeSearchFilters->getCaseSensitiveCheckBox()->setChecked(false);
+  mpTreeSearchFilters->getCaseSensitiveCheckBox()->blockSignals(signalsState);
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+  mpTVariableTreeProxyModel->setFilterRegularExpression(QRegularExpression());
+#else
+  mpTVariableTreeProxyModel->setFilterRegExp(QRegExp());
+#endif
+  /* clear equations tree */
+  clearTreeWidgetItems(mpEquationsTreeWidget);
+  /* clear defines in tree */
+  clearTreeWidgetItems(mpDefinesVariableTreeWidget);
+  /* clear depends tree */
+  clearTreeWidgetItems(mpDependsVariableTreeWidget);
+  /* clear equation operations tree */
+  clearTreeWidgetItems(mpEquationOperationsTreeWidget);
+  /* clear TSourceEditor */
+  mpTSourceEditorFileLabel->setText("");
+  mpTSourceEditorFileLabel->hide();
+  mpTransformationsEditor->getPlainTextEdit()->clear();
+  mpTSourceEditorInfoBar->hide();
+  /* Clear the equations tree. */
+  clearTreeWidgetItems(mpEquationsTreeWidget);
+  /* initialize all fields again */
+  mProfilingJSONFullFileName = "";
+  mProfilingDataRealFileName = "";
+  /* check if profiling is enabled or checkProfilingExists is true then check if the profiling files exists
+   * if user enabled profiling in the SimulationSetup then profiling will be true
+   * checkProfilingExists is true when user opens the transformation file
+   */
+  if (mProfilingEnabled || mCheckForProfilingFiles) {
+    QString profilingJSONFileName = mInfoJSONFullFileName.left(mInfoJSONFullFileName.size() - 9) + "prof.json";
+    QString profilingDataRealFileName = mInfoJSONFullFileName.left(mInfoJSONFullFileName.size() - 9) + "prof.realdata";
+    if (QFile::exists(profilingJSONFileName) && QFile::exists(profilingDataRealFileName)) {
+      mProfilingJSONFullFileName = profilingJSONFileName;
+      mProfilingDataRealFileName = profilingDataRealFileName;
+    }
+  }
   mEquations.clear();
   mVariables.clear();
   hasOperationsEnabled = false;
@@ -976,7 +1121,7 @@ void TransformationsWidget::loadTransformations()
         hasOperationsEnabled = true;
       }
     }
-    parseProfiling(mProfJSONFullFileName);
+    parseProfiling(mProfilingJSONFullFileName);
     fetchEquations();
   } else {
     QFile file(mInfoJSONFullFileName);
@@ -985,105 +1130,13 @@ void TransformationsWidget::loadTransformations()
     mpTVariablesTreeModel->insertTVariablesItems(mVariables);
     mpTVariablesTreeView->setSortingEnabled(true);
     /* load equations */
-    parseProfiling(mProfJSONFullFileName);
+    parseProfiling(mProfilingJSONFullFileName);
     fetchEquations();
     hasOperationsEnabled = mpInfoXMLFileHandler->hasOperationsEnabled;
   }
   fetchVariableData(mpTVariableTreeProxyModel->index(0, 0));
 }
 
-void TransformationsWidget::fetchDefinedInEquations(const OMVariable &variable)
-{
-  /* Clear the defined in tree. */
-  clearTreeWidgetItems(mpDefinedInEquationsTreeWidget);
-  /* add defined in equations */
-  for (int i=0; i<variable.definedIn.size(); i++) {
-    OMEquation *equation = getOMEquation(mEquations, variable.definedIn[i]);
-    if (equation) {
-      QStringList values;
-      values << QString::number(variable.definedIn[i]) << equation->section << equation->toString();
-      QTreeWidgetItem *pDefinedInTreeItem = new IntegerTreeWidgetItem(values, mpDefinedInEquationsTreeWidget);
-      pDefinedInTreeItem->setToolTip(0, values[0]);
-      pDefinedInTreeItem->setToolTip(1, values[1]);
-      pDefinedInTreeItem->setToolTip(2, values[2]);
-      mpDefinedInEquationsTreeWidget->addTopLevelItem(pDefinedInTreeItem);
-    }
-  }
-}
-
-void TransformationsWidget::fetchUsedInEquations(const OMVariable &variable)
-{
-  /* Clear the used in tree. */
-  clearTreeWidgetItems(mpUsedInEquationsTreeWidget);
-  /* add used in equations */
-  foreach (int index, variable.usedIn) {
-    OMEquation *equation = getOMEquation(mEquations, index);
-    if (equation) {
-      QStringList values;
-      values << QString::number(index) << equation->section << equation->toString();
-      QTreeWidgetItem *pUsedInTreeItem = new IntegerTreeWidgetItem(values, mpUsedInEquationsTreeWidget);
-      pUsedInTreeItem->setToolTip(0, values[0]);
-      pUsedInTreeItem->setToolTip(1, values[1]);
-      pUsedInTreeItem->setToolTip(2, values[2]);
-      mpUsedInEquationsTreeWidget->addTopLevelItem(pUsedInTreeItem);
-    }
-  }
-}
-
-void TransformationsWidget::fetchOperations(const OMVariable &variable)
-{
-  /* Clear the operations tree. */
-  clearTreeWidgetItems(mpVariableOperationsTreeWidget);
-  /* add operations */
-  if (hasOperationsEnabled) {
-    foreach (OMOperation *op, variable.ops) {
-      QTreeWidgetItem *pOperationTreeItem = new QTreeWidgetItem();
-      mpVariableOperationsTreeWidget->addTopLevelItem(pOperationTreeItem);
-      // set label item
-      Label *opText = new Label("<html><div style=\"margin:3px;\">" + op->toHtml() + "</div></html>");
-      mpVariableOperationsTreeWidget->setItemWidget(pOperationTreeItem, 0, opText);
-    }
-  } else {
-    QString message = GUIMessages::getMessage(GUIMessages::SET_INFO_XML_FLAG).arg(Helper::toolsOptionsPath).arg(Helper::toolsOptionsPath);
-    QStringList values;
-    values << message;
-    QString toolTip = message;
-    QTreeWidgetItem *pOperationTreeItem = new QTreeWidgetItem(values);
-    pOperationTreeItem->setToolTip(0, toolTip);
-    mpVariableOperationsTreeWidget->addTopLevelItem(pOperationTreeItem);
-  }
-  mpVariableOperationsTreeWidget->resizeColumnToContents(0);
-}
-
-QTreeWidgetItem* TransformationsWidget::makeEquationTreeWidgetItem(int equationIndex, int allowChild)
-{
-  OMEquation *equation = mEquations[equationIndex];
-  if (!allowChild && equation->parent) {
-    return NULL; // Only output equations in one position
-  }
-  QStringList values;
-  values << QString::number(equation->index)
-         << equation->section
-         << equation->toString();
-  if (equation->profileBlock >= 0) {
-    values << QString::number(equation->ncall)
-         << QString::number(equation->maxTime, 'g', 3)
-         << QString::number(equation->time, 'g', 3)
-         << QString::number(100 * equation->fraction, 'g', 3) + "%";
-  }
-
-  QTreeWidgetItem *pEquationTreeItem = new IntegerTreeWidgetItem(values, mpEquationsTreeWidget);
-  pEquationTreeItem->setToolTip(0, values[0]);
-  pEquationTreeItem->setToolTip(1, values[1]);
-  pEquationTreeItem->setToolTip(2, "<html><div style=\"margin:3px;\">" +
-  QString(values[2]).toHtmlEscaped()
-  + "</div></html>");
-  pEquationTreeItem->setToolTip(4, "Maximum execution time in a single step");
-  pEquationTreeItem->setToolTip(5, "Total time excluding the overhead of measuring.");
-  pEquationTreeItem->setToolTip(6, "Fraction of time, 100% is the total time of all non-child equations.");
-  return pEquationTreeItem;
-}
-
 void TransformationsWidget::fetchEquations()
 {
   for (int i = 1 ; i < mEquations.size() ; i++)
@@ -1185,10 +1238,9 @@ void TransformationsWidget::fetchEquationData(int equationIndex)
     }
   }
   QFile file(fileName);
-  if (file.exists()) {
+  if (file.open(QIODevice::ReadOnly)) {
     mpTSourceEditorFileLabel->setText(file.fileName());
     mpTSourceEditorFileLabel->show();
-    file.open(QIODevice::ReadOnly);
     mpTransformationsEditor->getPlainTextEdit()->setPlainText(QString(file.readAll()));
     mpTSourceEditorInfoBar->hide();
     file.close();
@@ -1257,7 +1309,7 @@ void TransformationsWidget::fetchOperations(OMEquation *equation, HtmlDiff htmlD
       }
     }
   } else {
-    QString message = GUIMessages::getMessage(GUIMessages::SET_INFO_XML_FLAG).arg(Helper::toolsOptionsPath).arg(Helper::toolsOptionsPath);
+    QString message = GUIMessages::getMessage(GUIMessages::SET_INFO_XML_FLAG).arg(Helper::toolsOptionsPath);
     QStringList values;
     values << message;
     QString toolTip = message;
@@ -1279,51 +1331,6 @@ void TransformationsWidget::clearTreeWidgetItems(QTreeWidget *pTreeWidget)
   }
 }
 
-void TransformationsWidget::reloadTransformations()
-{
-  mCurrentEquationIndex = 0;
-  /* clear trees */
-  mpTVariablesTreeModel->clearTVariablesTreeItems();
-  /* Clear the defined in tree. */
-  clearTreeWidgetItems(mpDefinedInEquationsTreeWidget);
-  /* Clear the used in tree. */
-  clearTreeWidgetItems(mpUsedInEquationsTreeWidget);
-  /* Clear the variable operations tree. */
-  clearTreeWidgetItems(mpVariableOperationsTreeWidget);
-  /* clear the variable tree filters. */
-  bool signalsState = mpTreeSearchFilters->getFilterTextBox()->blockSignals(true);
-  mpTreeSearchFilters->getFilterTextBox()->clear();
-  mpTreeSearchFilters->getFilterTextBox()->blockSignals(signalsState);
-  signalsState = mpTreeSearchFilters->getSyntaxComboBox()->blockSignals(true);
-  mpTreeSearchFilters->getSyntaxComboBox()->setCurrentIndex(0);
-  mpTreeSearchFilters->getSyntaxComboBox()->blockSignals(signalsState);
-  signalsState = mpTreeSearchFilters->getCaseSensitiveCheckBox()->blockSignals(true);
-  mpTreeSearchFilters->getCaseSensitiveCheckBox()->setChecked(false);
-  mpTreeSearchFilters->getCaseSensitiveCheckBox()->blockSignals(signalsState);
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
-  mpTVariableTreeProxyModel->setFilterRegularExpression(QRegularExpression());
-#else
-  mpTVariableTreeProxyModel->setFilterRegExp(QRegExp());
-#endif
-  /* clear equations tree */
-  clearTreeWidgetItems(mpEquationsTreeWidget);
-  /* clear defines in tree */
-  clearTreeWidgetItems(mpDefinesVariableTreeWidget);
-  /* clear depends tree */
-  clearTreeWidgetItems(mpDependsVariableTreeWidget);
-  /* clear equation operations tree */
-  clearTreeWidgetItems(mpEquationOperationsTreeWidget);
-  /* clear TSourceEditor */
-  mpTSourceEditorFileLabel->setText("");
-  mpTSourceEditorFileLabel->hide();
-  mpTransformationsEditor->getPlainTextEdit()->clear();
-  mpTSourceEditorInfoBar->hide();
-  /* Clear the equations tree. */
-  clearTreeWidgetItems(mpEquationsTreeWidget);
-  /* initialize all fields again */
-  loadTransformations();
-}
-
 /*!
  * \brief TransformationsWidget::findVariables
  * Finds the variables in the TransformationsWidget Variable Browser.
@@ -1377,10 +1384,9 @@ void TransformationsWidget::fetchVariableData(const QModelIndex &index)
     }
   }
   QFile file(fileName);
-  if (file.exists()) {
+  if (file.open(QIODevice::ReadOnly)) {
     mpTSourceEditorFileLabel->setText(file.fileName());
     mpTSourceEditorFileLabel->show();
-    file.open(QIODevice::ReadOnly);
     mpTransformationsEditor->getPlainTextEdit()->setPlainText(QString(file.readAll()));
     mpTSourceEditorInfoBar->hide();
     file.close();
