@@ -45,6 +45,8 @@ class UtilitiesTest: public QObject
   Q_OBJECT
 
 private slots:
+  void extractArrayParts();
+  void extractArrayParts_data();
   void literalConstant();
   void literalConstant_data();
   void scalarLiteralConstant();
