@@ -30,14 +30,15 @@
  */
 
 #include "PlotCurve.h"
-#if QWT_VERSION < 0x060000
-#include "qwt_legend_item.h"
-#else
-#include "qwt_painter.h"
-#endif
+#include "OMPlot.h"
+
 #include "qwt_symbol.h"
+#include "qwt_text.h"
 #include "qwt_scale_map.h"
-#include "qwt_point_polar.h"
+#include "qwt_math.h"
+
+#include <QtMath>
+#include <QStringBuilder>
 
 using namespace OMPlot;
 
@@ -58,6 +59,7 @@ PlotCurve::PlotCurve(const QString &fileName, const QString &absoluteFilePath, c
   setYDisplayUnit(yDisplayUnit);
   mCustomTitle = "";
   setToggleSign(false);
+  setYAxisRight(false);  // default to left y-axis
   setTitleLocal();
   /* set curve width and style */
   setCurveWidth(mpParentPlot->getParentPlotWindow()->getCurveWidth());
@@ -78,13 +80,13 @@ void PlotCurve::setTitleLocal()
   if (mCustomTitle.isEmpty()) {
     QString titleStr = getYVariable();
     if (!getYDisplayUnit().isEmpty() || !getYUnitPrefix().isEmpty()) {
-      titleStr += QString(" (%1%2)").arg(getYUnitPrefix(), getYDisplayUnit());
+      titleStr += QString(" (%1)").arg(Plot::convertUnitToSymbol(getYUnitPrefix() % getYDisplayUnit()));
     }
 
     if (mpParentPlot->getParentPlotWindow()->isPlotParametric() || mpParentPlot->getParentPlotWindow()->isPlotArrayParametric()) {
       QString xVariable = getXVariable();
       if (!getXDisplayUnit().isEmpty() || !getXUnitPrefix().isEmpty()) {
-        xVariable += QString(" (%1%2)").arg(getXUnitPrefix(), getXDisplayUnit());
+        xVariable += QString(" (%1)").arg(Plot::convertUnitToSymbol(getXUnitPrefix() % getXDisplayUnit()));
       }
       if (!xVariable.isEmpty()) {
         titleStr += QString(" <b>vs</b> %1").arg(xVariable);
@@ -93,6 +95,10 @@ void PlotCurve::setTitleLocal()
     // Add - sign if curve is toggled
     if (getToggleSign()) {
       titleStr.prepend(QString("-"));
+    }
+     // Append right arrow if curve is plotted on right axis
+    if (isYAxisRight()) {
+      titleStr.append(QChar(0x2794)); 
     }
     setTitle(titleStr);
     // visibility
@@ -252,12 +258,23 @@ void PlotCurve::toggleVisibility(bool visibility)
 }
 
 /*!
- * \brief PlotCurve::resetPrefixUnit
- * Resets the unit prefix.
- */
-void PlotCurve::resetPrefixUnit()
+ * \brief PlotCurve::setYAxisRight
+ * Assigns the curve to the right or left y-axis
+*/
+void PlotCurve::setYAxisRight(bool right)
 {
-  if (!mXUnitPrefix.isEmpty()) {
+    auto axis = right ? QwtPlot::yRight : QwtPlot::yLeft;
+    QwtPlotCurve::setYAxis(axis);
+}
+
+/*!
+ * \brief PlotCurve::resetPrefixUnit
+ * Resets the unit prefix and exponent.
+ * \param resetValues - reset the values.
+ */
+void PlotCurve::resetPrefixUnit(bool resetValues)
+{
+  if (!mXUnitPrefix.isEmpty() && resetValues) {
     for (int i = 0 ; i < mXAxisVector.size() ; i++) {
       updateXAxisValue(i, mXAxisVector.at(i) * qPow(10, mXExponent));
     }
@@ -265,7 +282,7 @@ void PlotCurve::resetPrefixUnit()
   mXUnitPrefix = "";
   mXExponent = 0;
 
-  if (!mYUnitPrefix.isEmpty()) {
+  if (!mYUnitPrefix.isEmpty() && resetValues) {
     for (int i = 0 ; i < mYAxisVector.size() ; i++) {
       updateYAxisValue(i, mYAxisVector.at(i) * qPow(10, mYExponent));
     }
@@ -330,7 +347,7 @@ void PlotCurve::plotData(bool toggleSign)
       }
     } else {
       // revert the values when there is no perfixUnits.
-      resetPrefixUnit();
+      resetPrefixUnit(true);
     }
   }
   setSamples(mXAxisVector, mYAxisVector);
