@@ -37,7 +37,7 @@
 #include "OMTLMSimulatorLib/OMTLMSimulatorLib.h"
 #include "ssd/Tags.h"
 #include "SystemWC.h"
-#include "Types.h"
+#include "OMSimulator/Types.h"
 
 #include <thread>
 #include <algorithm>
@@ -80,12 +80,8 @@ oms::System* oms::SystemTLM::NewSystem(const oms::ComRef& cref, oms::Model* pare
 
 oms_status_enu_t oms::SystemTLM::exportToSSD_SimulationInformation(pugi::xml_node& node) const
 {
-  pugi::xml_node node_annotations = node.append_child(oms::ssp::Draft20180219::ssd::annotations);
-  pugi::xml_node node_annotation = node_annotations.append_child(oms::ssp::Version1_0::ssc::annotation);
-  node_annotation.append_attribute("type") = oms::ssp::Draft20180219::annotation_type;
-
   /* ssd:SimulationInformation should be added as vendor specific annotations from Version 1.0 */
-  pugi::xml_node node_simulation_information = node_annotation.append_child(oms::ssp::Version1_0::simulation_information);
+  pugi::xml_node node_simulation_information = node.append_child(oms::ssp::Version1_0::simulation_information);
 
   pugi::xml_node node_tlm = node_simulation_information.append_child(oms::ssp::Draft20180219::tlm_master);
 
@@ -126,7 +122,7 @@ oms_status_enu_t oms::SystemTLM::importFromSSD_SimulationInformation(const pugi:
   return oms_status_ok;
 }
 
-oms_status_enu_t oms::SystemTLM::importFromSSD_SimulationInformationHelper(const pugi::xml_node & node)
+oms_status_enu_t oms::SystemTLM::importFromSSD_SimulationInformationHelper(const pugi::xml_node& node)
 {
   pugi::xml_node tlmmasterNode = node.child("oms::ssp::Draft20180219::tlm_master");
   for (auto it = tlmmasterNode.attributes_begin(); it != tlmmasterNode.attributes_end(); ++it)
@@ -153,7 +149,7 @@ oms_status_enu_t oms::SystemTLM::instantiate()
 
 oms_status_enu_t oms::SystemTLM::initialize()
 {
-  omtlm_setLogStepSize(model, getModel()->getLoggingInterval());
+  omtlm_setLogStepSize(model, getModel().getLoggingInterval());
 
   actualManagerPort = desiredManagerPort;
   actualMonitorPort = desiredMonitorPort;
@@ -201,7 +197,7 @@ oms_status_enu_t oms::SystemTLM::initialize()
     ExternalModel* externalmodel = reinterpret_cast<ExternalModel*>(component.second);
 
     //Copy external model file to temporary directory
-    std::string tempModelPath = getModel()->getTempDirectory()+"/"+std::string(externalmodel->getCref());
+    std::string tempModelPath = getModel().getTempDirectory()+"/"+std::string(externalmodel->getCref());
 
   #ifdef WIN32
     std::string cmd = "mkdir \""+tempModelPath+"\" 2> NUL";
@@ -261,8 +257,8 @@ oms_status_enu_t oms::SystemTLM::initialize()
     omtlm_addConnection(model,connections[i]->getSignalA().c_str(),connections[i]->getSignalB().c_str(),tlmpars->delay,tlmpars->linearimpedance,tlmpars->angularimpedance,tlmpars->alpha);
   }
 
-  logStep = (getModel()->getLoggingInterval() > 0) ? getModel()->getLoggingInterval() : 1e-3;
-  nextLogTime = getModel()->getStartTime()+logStep;
+  logStep = (getModel().getLoggingInterval() > 0) ? getModel().getLoggingInterval() : 1e-3;
+  nextLogTime = getModel().getStartTime()+logStep;
 
   return oms_status_ok;
 }
@@ -283,9 +279,14 @@ oms_status_enu_t oms::SystemTLM::reset()
   return oms_status_ok;
 }
 
-oms_status_enu_t oms::SystemTLM::stepUntil(double stopTime, void (*cb)(const char* ident, double time, oms_status_enu_t status))
+oms_status_enu_t oms::SystemTLM::doStep()
 {
-  omtlm_setStartTime(model, getModel()->getStartTime());
+  return logError_NotForTlmSystem;
+}
+
+oms_status_enu_t oms::SystemTLM::stepUntil(double stopTime)
+{
+  omtlm_setStartTime(model, getModel().getStartTime());
   omtlm_setStopTime(model, stopTime);
 
   if(getSubSystems().empty() && getComponents().empty())
@@ -377,7 +378,7 @@ oms_status_enu_t oms::SystemTLM::connectToSockets(const oms::ComRef cref, std::s
   logInfo("Initializing plugin for "+std::string(cref));
 
   if(!plugin->Init(std::string(cref),
-                   getModel()->getStartTime(),
+                   getModel().getStartTime(),
                    1, //Unused argument anyway
                    system->getMaximumStepSize(),
                    server)) {
@@ -420,10 +421,10 @@ void oms::SystemTLM::disconnectFromSockets(const oms::ComRef cref)
   }
 }
 
-oms_status_enu_t oms::SystemTLM::setSocketData(const std::string &address, int managerPort, int monitorPort)
+oms_status_enu_t oms::SystemTLM::setSocketData(const std::string& address, int managerPort, int monitorPort)
 {
-  if (!getModel()->validState(oms_modelState_virgin))
-    return logError_ModelInWrongState(this);
+  if (!getModel().validState(oms_modelState_virgin))
+    return logError_ModelInWrongState(getModel().getCref());
 
   this->address = address;
   this->desiredManagerPort = managerPort;
@@ -574,7 +575,7 @@ oms_status_enu_t oms::SystemTLM::updateInitialValues(const oms::ComRef cref)
 
 oms_status_enu_t oms::SystemTLM::initializeSubSystem(oms::ComRef cref)
 {
-  oms_status_enu_t status = getSubSystem(cref)->initialize();
+  oms_status_enu_t status = getSystem(cref)->initialize();
   if(oms_status_ok != status)
     return status;
   status = updateInitialValues(cref);
@@ -588,8 +589,8 @@ oms_status_enu_t oms::SystemTLM::initializeSubSystem(oms::ComRef cref)
 
 oms_status_enu_t oms::SystemTLM::simulateSubSystem(oms::ComRef cref, double stopTime)
 {
-  oms_status_enu_t status = getSubSystem(cref)->stepUntil(stopTime, NULL);
-  plugins[getSubSystem(cref)]->AwaitClosePermission();
+  oms_status_enu_t status = getSystem(cref)->stepUntil(stopTime);
+  plugins[getSystem(cref)]->AwaitClosePermission();
   return status;
 }
 
@@ -850,7 +851,7 @@ void oms::SystemTLM::sendValueToLogger(int varId, double time, double value)
   if(tmax >= nextLogTime && logBuffer.size() == numLogVars)
   {
     logTime = nextLogTime;
-    getModel()->emit(nextLogTime);
+    getModel().emit(nextLogTime);
     nextLogTime += logStep;
   }
 
